SystemOrganization addCategory: #'Seaside-Tests-Canvas'!

WAContextTest subclass: #WABuilderCanvasTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Canvas'!

!WABuilderCanvasTest methodsFor: 'testing' stamp: 'pmm 8/18/2007 12:40'!
testBody
	| actual |
	actual := WARenderCanvas builder render: [ :html |
		html unorderedList: [
			html listItem: 'an item' ] ].
	self assert: actual = '<ul><li>an item</li></ul>'! !

!WABuilderCanvasTest methodsFor: 'testing' stamp: 'jf 1/23/2009 03:33'!
testFullDocument
	| actual |
	actual := WARenderCanvas builder fullDocument: true; render: [ :html |
		html unorderedList: [
			html listItem: 'an item' ] ].
	self assert: actual = '<html><head><title></title></head><body><ul><li>an item</li></ul><script type="text/javascript">/*<!![CDATA[*/function onLoad(){}/*]]>*/</script></body></html>'! !

!WABuilderCanvasTest methodsFor: 'testing' stamp: 'jf 1/23/2009 03:33'!
testFullDocumentWithBlock
	| actual |
	actual := WARenderCanvas builder fullDocument: true;
		rootBlock: [ :root |
			root title: 'title' ];
		render: [ :html |
			html unorderedList: [
				html listItem: 'an item' ] ].
	self assert: actual = '<html><head><title>title</title></head><body><ul><li>an item</li></ul><script type="text/javascript">/*<!![CDATA[*/function onLoad(){}/*]]>*/</script></body></html>'! !

WAContextTest subclass: #WACanvasBrushTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Canvas'!

!WACanvasBrushTest methodsFor: 'private' stamp: 'jf 10/19/2008 02:18'!
assert: aBlock gives: aString
	| html |
	html := WARenderCanvas builder
		render: aBlock.
	self
		assert: html = aString
		description:	'Expected: ' , aString printString , ', Actual: ' , html printString
		resumable: true! !

!WACanvasBrushTest methodsFor: 'testing-tags-anchors' stamp: 'lr 12/28/2008 11:30'!
testAnchor
	self
		assert: [ :html | html anchor ]
		gives: '<a></a>'.
	self
		assert: [ :html | html anchor callback: [ ]; with: 'foo' ]
		gives: '<a href="/?1">foo</a>'.
	self
		assert: [ :html |
			html anchor callback: [ ]; with: 'foo'.
			html anchor callback: [ ]; with: 'bar' ]
		gives: '<a href="/?1">foo</a><a href="/?2">bar</a>'.
	self
		assert: [ :html |
			html anchor
				extraPath: 'zork';
				callback: [ ];
				with: 'foo'. ]
		gives: '<a href="/zork?1">foo</a>'.
	self
		assert: [ :html |
			html anchor
				extraParameters: 'zork';
				callback: [ ];
				with: 'foo'. ]
		gives: '<a href="/?zork&amp;1">foo</a>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-anchors' stamp: 'lr 12/28/2008 11:20'!
testAnchorAttributes
	self
		assert: [ :html | html anchor charset: 'utf-8' ]
		gives: '<a charset="utf-8"></a>'.
	self
		assert: [ :html | html anchor name: 'foo' ]
		gives: '<a name="foo"></a>'.
	self
		assert: [ :html | html anchor relationship: 'home' ]
		gives: '<a rel="home"></a>'.
	self
		assert: [ :html | html anchor relationship: 'home'; relationship: 'parent' ]
		gives: '<a rel="home parent"></a>'.
	self
		assert: [ :html | html anchor reverse: 'home' ]
		gives: '<a rev="home"></a>'.
	self
		assert: [ :html | html anchor reverse: 'home'; reverse: 'parent' ]
		gives: '<a rev="home parent"></a>'.
	self
		assert: [ :html | html anchor target: '_new' ]
		gives: '<a target="_new"></a>'.
	self
		assert: [ :html | html anchor type: 'text/plain' ]
		gives: '<a type="text/plain"></a>'
! !

!WACanvasBrushTest methodsFor: 'testing-tags-anchors' stamp: 'lr 12/28/2008 11:29'!
testAnchorCallback
	self
		assert: [ :html | html anchor callback: [ ] ]
		gives: '<a href="/?1"></a>'.
		
	self
		assert: [ :html | 
			self 
				should: [ html anchor callback: [ :value | ] ]
				raise: Error ]
		gives: '<a></a>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-anchors' stamp: 'lr 12/28/2008 11:31'!
testAnchorUrl
	| url string |
	url := WAUrl new.
	url
		hostname: 'www.seaside.st';
		addToPath: 'foo bar&zork<blah';
		addParameter: '1' value: nil;
		addParameter: '2' value: 123;
		addParameter: '3' value: 'foo bar&zork'.
	string := 'http://www.seaside.st/foo%20bar%26zork%3Cblah?1&amp;2=123&amp;3=foo%20bar%26zork'.
	self
		assert: [ :html | html anchor url: url; with: url ]
		gives: '<a href="' , string , '">' , string , '</a>'! !

!WACanvasBrushTest methodsFor: 'testing' stamp: 'lr 4/9/2007 18:28'!
testBasicNesting
	self assert: [ :html | html div ] gives: '<div></div>'.
	self assert: [ :html | html div: 1 ] gives: '<div>1</div>'.
	self assert: [ :html | html div: 'foo' ] gives: '<div>foo</div>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'lr 5/31/2008 18:35'!
testBlock
	self
		assert: [ :html | html strong: [ html text: 'nes'; text: 'sie' ] ]
		gives: '<strong>nessie</strong>'.
	self
		assert: [ :html | html strong: [ :html2 | html2 text: 'nes'; text: 'sie' ] ]
		gives: '<strong>nessie</strong>'.! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'lr 5/23/2007 12:09'!
testBreakTag
	self
		assert: [ :html | html break ]
		gives: '<br/>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-forms' stamp: 'lr 4/11/2008 08:55'!
testButton
	self
		assert: [ :html | html button ]
		gives: '<button type="submit" class="submit"></button>'.
	self
		assert: [ :html | html button text: 'foo' ]
		gives: '<button type="submit" class="submit">foo</button>'.
	self
		assert: [ :html | html button with: 'foo' ]
		gives: '<button type="submit" class="submit">foo</button>'.
	self
		assert: [ :html | html button beSubmit ]
		gives: '<button type="submit" class="submit"></button>'.
	self
		assert: [ :html | html button bePush ]
		gives: '<button type="button" class="button"></button>'.
	self
		assert: [ :html | html button beReset ]
		gives: '<button type="reset" class="reset"></button>'! !

!WACanvasBrushTest methodsFor: 'testing-encoding' stamp: 'pmm 8/29/2008 18:18'!
testByteArray
	self
		assert: [ :html | html render: #(83 101 97 115 105 100 101) asByteArray ]
		gives: 'Seaside'! !

!WACanvasBrushTest methodsFor: 'testing-tags-forms' stamp: 'lr 4/11/2008 09:03'!
testCancelButton
	self
		assert: [ :html | html cancelButton ]
		gives: '<input type="submit" class="submit"/>'.
	self
		assert: [ :html | html cancelButton callback: [ ] ]
		gives: '<input name="1" type="submit" class="submit"/>'.
	self
		assert: [ :html | html cancelButton on: #value of: self ]
		gives: '<input value="Value" name="1" type="submit" class="submit"/>'.
	self
		assert: [ :html | html cancelButton: 'foo' ]
		gives: '<input value="foo" type="submit" class="submit"/>'.
	self
		assert: [ :html | html cancelButton text: 'bar' ]
		gives: '<input value="bar" type="submit" class="submit"/>'.
	self
		assert: [ :html | html cancelButton with: 'zork' ]
		gives: '<input value="zork" type="submit" class="submit"/>'! !

!WACanvasBrushTest methodsFor: 'testing-encoding' stamp: 'lr 10/28/2007 14:42'!
testCanvasHtml
	self assert: [ :html | html html: '<' ] gives: '<'.
	self assert: [ :html | html html: '>' ] gives: '>'.
	self assert: [ :html | html html: '"' ] gives: '"'.
	self assert: [ :html | html html: '&' ] gives: '&'.
	self
		assert: [ :html | html html: '<div title="&amp;">' ]
		gives: '<div title="&amp;">'! !

!WACanvasBrushTest methodsFor: 'testing-encoding' stamp: 'pmm 10/20/2007 22:06'!
testCanvasNil
	self assert: [ :html | html text: nil ] gives: ''.
	self assert: [ :html | html render: nil ] gives: ''! !

!WACanvasBrushTest methodsFor: 'testing-encoding' stamp: 'lr 10/28/2007 14:42'!
testCanvasText
	self assert: [ :html | html text: '<' ] gives: '&lt;'.
	self assert: [ :html | html text: '>' ] gives: '&gt;'.
	self assert: [ :html | html text: '"' ] gives: '&quot;'.
	self assert: [ :html | html text: '&' ] gives: '&amp;'.
	self
		assert: [ :html | html text: '<div title="&amp;">' ]
		gives: '&lt;div title=&quot;&amp;amp;&quot;&gt;'! !

!WACanvasBrushTest methodsFor: 'testing-encoding' stamp: 'lr 10/28/2007 14:42'!
testCanvasWithLineBreaks
	self
		assert: [ :html | html withLineBreaks: 'a
b
c' ] gives: 'a<br/>b<br/>c'! !

!WACanvasBrushTest methodsFor: 'testing-encoding' stamp: 'lr 10/28/2007 14:42'!
testCanvasWithLineBreaksAndUrls
	self
		assert: [ :html | html withLineBreaksAndUrls: '1. This is http://www.seaside.st online.
2. This is http://www.squeak.org online.' ]
		gives: '1. This is <a href="http://www.seaside.st">http://www.seaside.st</a> online.<br/>2. This is <a href="http://www.squeak.org">http://www.squeak.org</a> online.'! !

!WACanvasBrushTest methodsFor: 'testing-encoding' stamp: 'lr 10/28/2007 14:42'!
testCanvasWithUrls
	self
		assert: [ :html | html withUrls: 'This is http://www.seaside.st online.' ]
		gives: 'This is <a href="http://www.seaside.st">http://www.seaside.st</a> online.'! !

!WACanvasBrushTest methodsFor: 'testing-tags-forms' stamp: 'jf 7/20/2008 09:54'!
testCheckboxTag
	self
		assert: [ :html | html checkbox ]
		gives: '<input type="checkbox" class="checkbox"/>'.
	self
		assert: [ :html | html checkbox value: true ]
		gives: '<input checked="checked" type="checkbox" class="checkbox"/>'.
	self
		assert: [ :html | html checkbox value: false; callback: [ :value | ] ]
		gives: '<input name="1" type="checkbox" class="checkbox"/><input name="2" type="hidden" class="hidden"/>'.
	self
		assert: [ :html | html checkbox value: true; callback: [ :value | ] ]
		gives: '<input checked="checked" name="1" type="checkbox" class="checkbox"/><input name="2" type="hidden" class="hidden"/>'! !

!WACanvasBrushTest methodsFor: 'testing' stamp: 'lr 10/28/2007 14:42'!
testClosingTimes
	self assert: [ :html | html div; div ] gives: '<div></div><div></div>'.
	self assert: [ :html | html break; div ] gives: '<br/><div></div>'.
	self assert: [ :html | html div; break ] gives: '<div></div><br/>'.
	self assert: [ :html | html break; break ] gives: '<br/><br/>'.

	self assert: [ :html | html div: [ html div ]; div ] gives: '<div><div></div></div><div></div>'.
	self assert: [ :html | html div: [ html break ]; div ] gives: '<div><br/></div><div></div>'.
	self assert: [ :html | html div: [ html div ]; break ] gives: '<div><div></div></div><br/>'.
	self assert: [ :html | html div: [ html break ]; break ] gives: '<div><br/></div><br/>'! !

!WACanvasBrushTest methodsFor: 'testing-attributes' stamp: 'lr 10/28/2007 14:42'!
testCoreAttributesClass
	self
		assert: [ :html | html div class: 'foo' ]
		gives: '<div class="foo"></div>'.
	self
		assert: [ :html | html div class: 'foo'; class: 'bar' ]
		gives: '<div class="foo bar"></div>'! !

!WACanvasBrushTest methodsFor: 'testing-attributes' stamp: 'lr 10/28/2007 14:42'!
testCoreAttributesId
	self
		assert: [ :html | html div id: 'foo' ]
		gives: '<div id="foo"></div>'.
	self
		assert: [ :html | html div id: 'foo'; id: 'bar' ]
		gives: '<div id="bar"></div>'.
	self
		assert: [ :html | self assert: (html div ensureId = 'id1') ]
		gives: '<div id="id1"></div>'.
	self
		assert: [ :html | self assert: (html div id: 'foo'; ensureId) = 'foo' ]
		gives: '<div id="foo"></div>'.
	self
		assert: [ :html | self assert: (html div id: 'foo'; id) = 'foo' ]
		gives: '<div id="foo"></div>'.
	self
		assert: [ :html | self assert: (html div id) isNil ]
		gives: '<div></div>'! !

!WACanvasBrushTest methodsFor: 'testing-attributes' stamp: 'lr 4/9/2007 18:18'!
testCoreAttributesStyle
	self
		assert: [ :html | html div style: 'left: 0' ]
		gives: '<div style="left: 0"></div>'.
	self
		assert: [ :html | html div style: 'left: 0'; style: 'top: 2' ]
		gives: '<div style="left: 0;top: 2"></div>'! !

!WACanvasBrushTest methodsFor: 'testing-attributes' stamp: 'lr 4/9/2007 18:18'!
testCoreAttributesTitle
	self
		assert: [ :html | html div title: 'Seaside' ]
		gives: '<div title="Seaside"></div>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'lr 4/28/2007 18:58'!
testEditTag
	self
		assert: [ :html | html inserted: 'foo' ]
		gives: '<ins>foo</ins>'.
	self
		assert: [ :html | html deleted: 'bar' ]
		gives: '<del>bar</del>'! !

!WACanvasBrushTest methodsFor: 'testing-attributes' stamp: 'lr 4/9/2007 18:23'!
testEventAttributes
	self
		assert: [ :html | html div onBlur: 1; onBlur: 2 ]
		gives: '<div onblur="1;2"></div>'.
	self
		assert: [ :html | html div onChange: 1; onChange: 2 ]
		gives: '<div onchange="1;2"></div>'.
	self
		assert: [ :html | html div onClick: 1; onClick: 2 ]
		gives: '<div onclick="1;2"></div>'.
	self
		assert: [ :html | html div onDoubleClick: 1; onDoubleClick: 2 ]
		gives: '<div ondblclick="1;2"></div>'! !

!WACanvasBrushTest methodsFor: 'testing' stamp: 'lr 4/9/2007 18:28'!
testExtendedNesting
	self assert: [ :html | html div: nil ] gives: '<div></div>'.
	self assert: [ :html | html div: #( 1 $a ) ] gives: '<div>1a</div>'.
	self assert: [ :html | html div: [ html span ] ] gives: '<div><span></span></div>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'lr 4/28/2007 19:01'!
testFieldSetTag
	self
		assert: [ :html | html fieldSet: 'foo' ]
		gives: '<fieldset>foo</fieldset>'.
	self
		assert: [ :html | html fieldSet legend: 'bar'; with: 'zork' ]
		gives: '<fieldset><legend>bar</legend>zork</fieldset>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'lr 6/6/2007 14:00'!
testHeadingTag
	self
		assert: [ :html | html heading ]
		gives: '<h1></h1>'.
	self
		assert: [ :html | html heading level: 2; with: 'foo' ]
		gives: '<h2>foo</h2>'.
	self
		assert: [ :html | html heading level: 0; with: 'foo' ]
		gives: '<h1>foo</h1>'.
	self
		assert: [ :html | html heading level: 7; with: 'foo' ]
		gives: '<h6>foo</h6>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'lr 5/23/2007 12:10'!
testHorizontalRuleTag
	self
		assert: [ :html | html horizontalRule ]
		gives: '<hr/>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-forms' stamp: 'lr 10/28/2007 14:42'!
testImageButton
	self
		assert: [ :html | html imageButton ]
		gives: '<input type="image" class="image"/>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'pmm 1/7/2008 18:41'!
testImageTag
	self
		assert: [ :html | html image url: 'http://www.seaside.st/logo.jpeg' ]
		gives: '<img alt="" src="http://www.seaside.st/logo.jpeg"/>'.
		
	self
		assert: [ :html |
			html image
				title: 'Seaside';
				altText: 'the Seaside logo';
				url: 'http://www.seaside.st/logo.jpeg' ]
		gives: '<img alt="the Seaside logo" title="Seaside" src="http://www.seaside.st/logo.jpeg"/>'! !

!WACanvasBrushTest methodsFor: 'testing-attributes' stamp: 'lr 12/28/2008 11:30'!
testKeyboardAttributes
	self
		assert: [ :html | html anchor accessKey: $a ]
		gives: '<a accesskey="a"></a>'.
	self
		assert: [ :html | html anchor tabIndex: 3 ]
		gives: '<a tabindex="3"></a>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'lr 4/28/2007 19:03'!
testLabelTag
	self
		assert: [ :html | html label: 'foo' ]
		gives: '<label>foo</label>'.
	self
		assert: [ :html | html label for: 'bar'; with: 'zork' ]
		gives: '<label for="bar">zork</label>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-anchors' stamp: 'lr 3/26/2008 22:36'!
testMapTag
	self
		assert: [ :html | html map callback: [ :point | ]; with: [ html image url: 'seaside.jpg' ] ]
		gives: '<a href="/?1="><img alt="" ismap="ismap" src="seaside.jpg"/></a>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-forms' stamp: 'lr 6/6/2007 19:31'!
testMultiSelectTag
	self
		assert: [ :html | html multiSelect ]
		gives: '<select multiple="multiple" name="1"></select>'.
	self
		assert: [ :html | html multiSelect list: #(1 2) ]
		gives: '<select multiple="multiple" name="1"><option>1</option><option>2</option></select>'.
	self
		assert: [ :html | html multiSelect list: #(1 2); labels: [ :v | 2 * v ] ]
		gives: '<select multiple="multiple" name="1"><option>2</option><option>4</option></select>'.
	self
		assert: [ :html | html multiSelect list: #(1 2); enabled: [ :v | v even ] ]
		gives: '<select multiple="multiple" name="1"><option disabled="disabled">1</option><option>2</option></select>'.
	self
		assert: [ :html | html multiSelect list: #(1 2); callback: [ :v | ] ]
		gives: '<input name="1" type="hidden" class="hidden"/><select multiple="multiple" name="2"><option value="3">1</option><option value="4">2</option></select><input name="5" type="hidden" class="hidden"/>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'lr 6/6/2007 13:54'!
testOrderedListTag
	self
		assert: [ :html | html orderedList ]
		gives: '<ol></ol>'.
	self
		assert: [ :html | html orderedList add: 1 ]
		gives: '<ol><li>1</li></ol>'.
	self
		assert: [ :html | html orderedList addAll: #( 1 2 ) ]
		gives: '<ol><li>1</li><li>2</li></ol>'.
	self
		assert: [ :html | html orderedList list: #( 1 2 ) ]
		gives: '<ol><li>1</li><li>2</li></ol>'.
	self
		assert: [ :html | html orderedList list: #( 1 2 ); with: [ html listItem: 3 ] ]
		gives: '<ol><li>1</li><li>2</li><li>3</li></ol>'.
	self
		assert: [ :html | html orderedList add: 2; labels: [ :e | 2 * e ] ]
		gives: '<ol><li>4</li></ol>'.
	self
		assert: [ :html | html orderedList add: 2; labels: [ :e | 2 * e ]; with: [ html listItem: 5 ] ]
		gives: '<ol><li>4</li><li>5</li></ol>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'lr 4/28/2007 18:55'!
testParagraphTag
	self
		assert: [ :html | html paragraph ]
		gives: '<p></p>'.
	self
		assert: [ :html | html paragraph: 'foo' ]
		gives: '<p>foo</p>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-forms' stamp: 'lr 4/11/2008 09:15'!
testPasswordInput
	self
		assert: [ :html | html passwordInput ]
		gives: '<input type="password" class="password"/>'.
	self
		assert: [ :html | html passwordInput callback: [ :value | ] ]
		gives: '<input name="1" type="password" class="password"/>'.
	self
		assert: [ :html | html passwordInput: 'foo' ]
		gives: '<input value="foo" type="password" class="password"/>'.
	self
		assert: [ :html | html passwordInput value: 'bar' ]
		gives: '<input value="bar" type="password" class="password"/>'.
	self
		assert: [ :html | html passwordInput text: 'zork' ]
		gives: '<input value="zork" type="password" class="password"/>'.
	self
		assert: [ :html | html passwordInput callback: [ :value | ]; value: 'foo bar&zork' ]
		gives: '<input name="1" value="foo bar&amp;zork" type="password" class="password"/>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'pmm 1/26/2008 20:14'!
testScriptTag
	self
		assert: [ :html | html script: 'alert("<foo>")' ]
		gives: '<script type="text/javascript">/*<!![CDATA[*/alert("<foo>")/*]]>*/</script>'.
	self
		assert: [ :html | html script: 'true & false' ]
		gives: '<script type="text/javascript">/*<!![CDATA[*/true & false/*]]>*/</script>'.
	self
		assert: [ :html | html script defer; with: 'alert("<foo>")' ]
		gives: '<script defer="defer" type="text/javascript">/*<!![CDATA[*/alert("<foo>")/*]]>*/</script>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-forms' stamp: 'lr 6/6/2007 18:52'!
testSelectTag
	self
		assert: [ :html | html select ]
		gives: '<select name="1"></select>'.
	self
		assert: [ :html | html select list: #(1 2) ]
		gives: '<select name="1"><option>1</option><option>2</option></select>'.
	self
		assert: [ :html | html select list: #(1 2); labels: [ :v | 2 * v ] ]
		gives: '<select name="1"><option>2</option><option>4</option></select>'.
	self
		assert: [ :html | html select list: #(1 2); enabled: [ :v | v even ] ]
		gives: '<select name="1"><option disabled="disabled">1</option><option>2</option></select>'.
	self
		assert: [ :html | html select list: #(1 2); callback: [ :v | ] ]
		gives: '<select name="1"><option value="2">1</option><option value="3">2</option></select>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-forms' stamp: 'lr 11/28/2008 14:10'!
testSubmitButton
	self
		assert: [ :html | html submitButton ]
		gives: '<input type="submit" class="submit"/>'.
	self
		assert: [ :html | html submitButton callback: [ ] ]
		gives: '<input name="1" type="submit" class="submit"/>'.
	self
		assert: [ :html | 
			self 
				should: [ html submitButton callback: [ :value | ] ]
				raise: Error ]
		gives: '<input type="submit" class="submit"/>'.
	self
		assert: [ :html | html submitButton on: #value of: self ]
		gives: '<input value="Value" name="1" type="submit" class="submit"/>'.
	self
		assert: [ :html | html submitButton: 'foo' ]
		gives: '<input value="foo" type="submit" class="submit"/>'.
	self
		assert: [ :html | html submitButton text: 'bar' ]
		gives: '<input value="bar" type="submit" class="submit"/>'.
	self
		assert: [ :html | html submitButton with: 'zork' ]
		gives: '<input value="zork" type="submit" class="submit"/>'! !

!WACanvasBrushTest methodsFor: 'testing-encoding' stamp: 'pmm 10/2/2007 06:53'!
testSymbolRendering
	self
		assert: [ :html | html div id: #aSymbol; with: #aSecondSymbol ]
		gives: '<div id="aSymbol">aSecondSymbol</div>'.
	self
		assert: [ :html | html div: [ html text: #aSecondSymbol ] ]
		gives: '<div>aSecondSymbol</div>'.
	self
		assert: [ :html | html div: [ html render: #aSecondSymbol ] ]
		gives: '<div>aSecondSymbol</div>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-tables' stamp: 'lr 3/24/2008 17:36'!
testTable
	self
		assert: [ :html | html table ]
		gives: '<table></table>'.
	self
		assert: [ :html | html table cellpadding: 0; cellspacing: 1 ]
		gives: '<table cellpadding="0" cellspacing="1"></table>'.
	self
		assert: [ :html | html table frame: 'box'; rules: 'groups' ]
		gives: '<table frame="box" rules="groups"></table>'.
	self
		assert: [ :html | html table summary: 'a short summary' ]
		gives: '<table summary="a short summary"></table>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-tables' stamp: 'lr 3/24/2008 17:32'!
testTableColumn
	self
		assert: [ :html | html tableColumn ]
		gives: '<col/>'.
	self
		assert: [ :html | html tableColumn character: '.'; characterOffset: 2 ]
		gives: '<col char="." charoff="2"/>'.
	self
		assert: [ :html | html tableColumn align: 'right'; verticalAlign: 'top' ]
		gives: '<col align="right" valign="top"/>'.
	self
		assert: [ :html | html tableColumn span: 3; width: '20' ]
		gives: '<col span="3" width="20"/>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-tables' stamp: 'lr 3/24/2008 17:33'!
testTableColumnGroup
	self
		assert: [ :html | html tableColumnGroup ]
		gives: '<colgroup></colgroup>'.
	self
		assert: [ :html | html tableColumnGroup character: '.'; characterOffset: 2 ]
		gives: '<colgroup char="." charoff="2"></colgroup>'.
	self
		assert: [ :html | html tableColumnGroup align: 'right'; verticalAlign: 'top' ]
		gives: '<colgroup align="right" valign="top"></colgroup>'.
	self
		assert: [ :html | html tableColumnGroup span: 3; width: '20' ]
		gives: '<colgroup span="3" width="20"></colgroup>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-tables' stamp: 'lr 3/24/2008 17:29'!
testTableData
	self
		assert: [ :html | html tableData ]
		gives: '<td></td>'.
	self
		assert: [ :html | html tableData character: '.'; characterOffset: 2 ]
		gives: '<td char="." charoff="2"></td>'.
	self
		assert: [ :html | html tableData align: 'right'; verticalAlign: 'top' ]
		gives: '<td align="right" valign="top"></td>'.
	self
		assert: [ :html | html tableData abbreviation: 'short'; with: 'longer' ]
		gives: '<td abbr="short">longer</td>'.
	self
		assert: [ :html | html tableData axis: 'time' ]
		gives: '<td axis="time"></td>'.
	self
		assert: [ :html | html tableData colSpan: 2; rowSpan: 3 ]
		gives: '<td colspan="2" rowspan="3"></td>'.
	self
		assert: [ :html | html tableData headers: 'zork' ]
		gives: '<td headers="zork"></td>'.
	self
		assert: [ :html | html tableData scope: 'colgroup' ]
		gives: '<td scope="colgroup"></td>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-tables' stamp: 'lr 12/28/2008 11:31'!
testTableFull
	self
		assert: [ :html | 
			html table: [
				html tableCaption: 'title'.
				html tableColumnGroup: [
					html tableColumn.
					html tableColumn ].
				html tableHead: [
					html tableRow: [ 
						html tableHeading: 'a1'.
						html tableHeading: 'a2' ] ].
				html tableFoot: [
					html tableRow: [ 
						html tableData: 'b1'.
						html tableData: 'b2' ] ].
				html tableBody: [
					html tableRow: [ 
						html tableData: 'c1'.
						html tableData: 'c2' ].
					html tableRow: [ 
						html tableData: 'd1'.
						html tableData: 'd2' ] ] ] ]
		gives: '<table><caption>title</caption><colgroup><col/><col/></colgroup><thead><tr><th>a1</th><th>a2</th></tr></thead><tfoot><tr><td>b1</td><td>b2</td></tr></tfoot><tbody><tr><td>c1</td><td>c2</td></tr><tr><td>d1</td><td>d2</td></tr></tbody></table>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-tables' stamp: 'lr 3/24/2008 17:30'!
testTableHeading
	self
		assert: [ :html | html tableHeading ]
		gives: '<th></th>'.
	self
		assert: [ :html | html tableHeading character: '.'; characterOffset: 2 ]
		gives: '<th char="." charoff="2"></th>'.
	self
		assert: [ :html | html tableHeading align: 'right'; verticalAlign: 'top' ]
		gives: '<th align="right" valign="top"></th>'.
	self
		assert: [ :html | html tableHeading abbreviation: 'short'; with: 'longer' ]
		gives: '<th abbr="short">longer</th>'.
	self
		assert: [ :html | html tableHeading axis: 'time' ]
		gives: '<th axis="time"></th>'.
	self
		assert: [ :html | html tableHeading colSpan: 2; rowSpan: 3 ]
		gives: '<th colspan="2" rowspan="3"></th>'.
	self
		assert: [ :html | html tableHeading headers: 'zork' ]
		gives: '<th headers="zork"></th>'.
	self
		assert: [ :html | html tableHeading scope: 'colgroup' ]
		gives: '<th scope="colgroup"></th>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-forms' stamp: 'lr 4/11/2008 08:56'!
testTextArea
	self
		assert: [ :html | html textArea ]
		gives: '<textarea rows="auto" cols="auto"></textarea>'.
	self
		assert: [ :html | html textArea columns: 4 ]
		gives: '<textarea rows="auto" cols="4"></textarea>'.
	self
		assert: [ :html | html textArea rows: 40 ]
		gives: '<textarea rows="40" cols="auto"></textarea>'.
	self
		assert: [ :html | html textArea callback: [ :value | ] ]
		gives: '<textarea rows="auto" cols="auto" name="1"></textarea>'.
	self
		assert: [ :html | html textArea: 'foo bar&zork' ]
		gives: '<textarea rows="auto" cols="auto">foo bar&amp;zork</textarea>'.
	self
		assert: [ :html | html textArea text: 'foo bar&zork' ]
		gives: '<textarea rows="auto" cols="auto">foo bar&amp;zork</textarea>'.
	self
		assert: [ :html | html textArea value: 'foo bar&zork' ]
		gives: '<textarea rows="auto" cols="auto">foo bar&amp;zork</textarea>'.
	self
		assert: [ :html | html textArea with: 'foo bar&zork' ]
		gives: '<textarea rows="auto" cols="auto">foo bar&amp;zork</textarea>'.
	self
		assert: [ :html | html textArea callback: [ :value | ]; with: 'foo bar&zork' ]
		gives: '<textarea rows="auto" cols="auto" name="1">foo bar&amp;zork</textarea>'! !

!WACanvasBrushTest methodsFor: 'testing-tags-forms' stamp: 'lr 4/11/2008 09:14'!
testTextInput
	self
		assert: [ :html | html textInput ]
		gives: '<input type="text" class="text"/>'.
	self
		assert: [ :html | html textInput callback: [ :value | ] ]
		gives: '<input name="1" type="text" class="text"/>'.
	self
		assert: [ :html | html textInput: 'foo' ]
		gives: '<input value="foo" type="text" class="text"/>'.
	self
		assert: [ :html | html textInput value: 'bar' ]
		gives: '<input value="bar" type="text" class="text"/>'.
	self
		assert: [ :html | html textInput text: 'zork' ]
		gives: '<input value="zork" type="text" class="text"/>'.
	self
		assert: [ :html | html textInput callback: [ :value | ]; value: 'foo bar&zork' ]
		gives: '<input name="1" value="foo bar&amp;zork" type="text" class="text"/>'! !

!WACanvasBrushTest methodsFor: 'testing-tags' stamp: 'lr 6/6/2007 13:55'!
testUnorderedListTag
	self
		assert: [ :html | html unorderedList ]
		gives: '<ul></ul>'.
	self
		assert: [ :html | html unorderedList add: 1 ]
		gives: '<ul><li>1</li></ul>'.
	self
		assert: [ :html | html unorderedList addAll: #( 1 2 ) ]
		gives: '<ul><li>1</li><li>2</li></ul>'.
	self
		assert: [ :html | html unorderedList list: #( 1 2 ) ]
		gives: '<ul><li>1</li><li>2</li></ul>'.
	self
		assert: [ :html | html unorderedList list: #( 1 2 ); with: [ html listItem: 3 ] ]
		gives: '<ul><li>1</li><li>2</li><li>3</li></ul>'.
	self
		assert: [ :html | html unorderedList add: 2; labels: [ :e | 2 * e ] ]
		gives: '<ul><li>4</li></ul>'.
	self
		assert: [ :html | html unorderedList add: 2; labels: [ :e | 2 * e ]; with: [ html listItem: 5 ] ]
		gives: '<ul><li>4</li><li>5</li></ul>'! !

WACanvasBrushTest subclass: #WAFormTagTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Canvas'!

!WAFormTagTest methodsFor: 'private' stamp: 'jf 10/19/2008 02:17'!
assertUserAgent: aString isInternetExplorer: aBoolean
	self userAgent: aString.
	WARenderCanvas builder
		render: [ :html |
			self assert: html form isInternetExplorer = aBoolean ]! !

!WAFormTagTest methodsFor: 'testing' stamp: 'MAD 8/30/2008 15:04'!
testBasicForm
	self
		assert: [ :html |
			html basicForm ]
		gives: '<form accept-charset="utf-8" method="post" action="/"></form>'.
! !

!WAFormTagTest methodsFor: 'testing' stamp: 'lr 3/26/2008 22:37'!
testDefaultAction
	self userAgent: 'Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3'.
	self
		assert: [ :html |
			html form defaultAction: [  ] ]
		gives: '<form accept-charset="utf-8" method="post" action="/"><div><input tabindex="-1" value="Default" name="1" style="position: absolute; top: -100em" type="submit" class="submit"/></div><div></div></form>'.
	
	self userAgent: 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)'.
	self
		assert: [ :html |
			html form
				defaultAction: [  ] ]
		gives: '<form accept-charset="utf-8" method="post" action="/"><div><input tabindex="-1" value="Default" name="1" style="position: absolute; top: -100em" type="submit" class="submit"/><input tabindex="-1" name="2" style="position: absolute; top: -100em" type="text" class="text"/></div><div></div></form>'.! !

!WAFormTagTest methodsFor: 'testing' stamp: 'pmm 11/25/2007 11:06'!
testIsInternetExplorer
	self assertUserAgent: 'Mozilla/5.0 (compatible; Konqueror/3.2; Linux 2.6.2) (KHTML, like Gecko)' isInternetExplorer: false.
	self assertUserAgent: 'Mozilla/4.0 (compatible; MSIE 6.0; MSIE 5.5; Windows NT 5.1) Opera 7.04 [de]' isInternetExplorer: false.
	self assertUserAgent: 'Opera/9.10 (Windows NT 5.0; U; de)' isInternetExplorer: false.
	self assertUserAgent: 'Mozilla/5.0 (Windows; U; Windows NT 5.0; de-DE; rv:1.6) Gecko/20040206 Firefox/1.0.1' isInternetExplorer: false.
	self assertUserAgent: 'Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 6.0; WOW64; SLCC1; .NET CLR 2.0.50727; .NET CLR 3.0.04506)' isInternetExplorer: true.
	self assertUserAgent: 'Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.0)' isInternetExplorer: true.
	self assertUserAgent: 'Lynx/2.8.4rel.1 libwww-FM/2.14 SSL-MM/1.4.1 OpenSSL/0.9.6c' isInternetExplorer: false.
	self assertUserAgent: 'Mozilla/5.0 (Windows; U; Windows NT 5.1; de-AT; rv:1.8.1.2) Gecko/20070222 SeaMonkey/1.1.1' isInternetExplorer: false.
	self assertUserAgent: 'Mozilla/5.0 (Windows; U; Windows NT 5.1; de; rv:1.8.1.3) Gecko/20070309 Firefox/2.0.0.3' isInternetExplorer: false.! !

!WAFormTagTest methodsFor: 'private' stamp: 'pmm 5/11/2008 09:33'!
userAgent: aString
	self requestContext request headers at: 'user-agent' put: aString! !

WAContextTest subclass: #WARenderingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Canvas'!

!WARenderingTest methodsFor: 'private' stamp: 'jf 1/23/2009 03:33'!
assert: aBlock gives: aString
	| html |
	html := WARenderCanvas builder
		fullDocument: true;
		rootBlock: aBlock;
		render: [ :canvas | ].
	self assert: html = ('<html><head>', aString, '</head><body><script type="text/javascript">/*<!![CDATA[*/function onLoad(){}/*]]>*/</script></body></html>')! !

!WARenderingTest methodsFor: 'testing' stamp: 'pmm 11/25/2007 11:17'!
testConditionalComment
	self
		assert: [ :html |
			html if greaterThan; orEqual; ie55; do: [
				html script
					defer;
					url: 'http://www.example.com/bugs.js' ] ]
		gives: '<title></title><!!--[if gte IE 5.5]><script defer="defer" src="http://www.example.com/bugs.js"></script><!![endif]-->'.
		
	self
		assert: [ :html |
			html if not; ie; do: [
				html script
					url: 'http://www.example.com/bugs.js' ] ]
		gives: '<title></title><!!--[if !! IE]><script src="http://www.example.com/bugs.js"></script><!![endif]-->'! !

!WARenderingTest methodsFor: 'testing' stamp: 'jf 9/22/2008 12:21'!
testContentType
	self
		assert: [ :html |
			html meta contentType: 'application/xhml+xml' seasideMimeType  ]
		gives: '<title></title><meta http-equiv="Content-Type" content="application/xhml+xml"/>'.
	self
		assert: [ :html |
			html meta contentType: 'application/xhml+xml'  ]
		gives: '<title></title><meta http-equiv="Content-Type" content="application/xhml+xml"/>'! !

!WARenderingTest methodsFor: 'testing' stamp: 'pmm 1/26/2008 20:14'!
testJavascript
	self
		assert: [ :html |
			html javascript
				add: 'true & false'  ]
		gives: '<title></title><script type="text/javascript">/*<!![CDATA[*/true & false/*]]>*/</script>'! !

!WARenderingTest methodsFor: 'testing' stamp: 'pmm 12/4/2007 20:23'!
testLinkElement
	self
		assert: [ :html |
			html stylesheet
				addAural;
				addTeletype;
				title: 'aTilte';
				url: 'http://example.com/style.css'  ]
		gives: '<title></title><link rel="stylesheet" type="text/css" media="aural, tty" title="aTilte" href="http://example.com/style.css"/>'! !

!WARenderingTest methodsFor: 'testing' stamp: 'pmm 1/29/2008 21:55'!
testLinkElementWithContent
	self
		assert: [ :html |
			html stylesheet
				add: 'div > em { color: blue; }'  ]
		gives: '<title></title><style type="text/css">/*<!![CDATA[*/div > em { color: blue; }/*]]>*/</style>'.
	self
		assert: [ :html |
			html stylesheet
				add: 'E[foo$="bar"]'  ]
		gives: '<title></title><style type="text/css">/*<!![CDATA[*/E[foo$="bar"]/*]]>*/</style>'
	! !

!WARenderingTest methodsFor: 'testing' stamp: 'pmm 11/25/2007 22:01'!
testRevealedConditionalComment
		self assert: [ :html |
			html revealedIf ie7; do: [
				html script
					defer;
					url: 'http://www.example.com/bugs.js' ] ]
		gives: '<title></title><!!--[if IE 7]><!!--><script defer="defer" src="http://www.example.com/bugs.js"></script><!!--<!![endif]-->'! !

!WAPackage class methodsFor: '*seaside-tests-canvas' stamp: 'lr 10/23/2008 21:30'!
seasideTestsCanvas
	^ self new
		name: 'Seaside-Tests-Canvas';
		description: 'Unit tests for the package Seaside-Canvas.';
		addDependency: 'Seaside-Canvas';
		addDependency: 'Seaside-Tests-Core';
		yourself! !

TestCase subclass: #WAEmailAddressTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Canvas'!

!WAEmailAddressTest methodsFor: 'private' stamp: 'jf 2/15/2009 20:53'!
render: anObject
	^ WARenderer builder
		documentClass: WAHtmlDocument;
		render: anObject! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 13:06'!
testAddress
	| address |
	address := WAEmailAddress address: 'philippe.marschall@gmail.com'.
	self assert: address address = 'philippe.marschall@gmail.com'.
	self assert: address username isNil.
	self assert: address seasideString = 'philippe.marschall@gmail.com'.! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 9/2/2008 14:15'!
testAddressUsername
	| address |
	address := WAEmailAddress
		address: 'philippe.marschall@gmail.com'
		username: 'Philippe Marschall'.
	self assert: address address = 'philippe.marschall@gmail.com'.
	self assert: address username = 'Philippe Marschall'.
	self assert: address seasideString = '"Philippe Marschall" <philippe.marschall@gmail.com>'.! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 13:39'!
testEmpty
	| address |
	address := WAEmailAddress address: (String with: Character cr with: Character lf), 'philippe.marschall@gmail.com'.
	self assert: address address = ''.
	self assert: address username isNil.
	self assert: address seasideString = ''.! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 8/31/2008 13:26'!
testInjection
	| address |
	address := WAEmailAddress address: 'philippe.marschall@gmail.com',
		(String with: Character cr with: Character lf),
		'Evil-Header: evil-value'.
	self assert: address address = 'philippe.marschall@gmail.com'.
	self assert: address username isNil.
	self assert: address seasideString = 'philippe.marschall@gmail.com'.! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 11/30/2008 15:28'!
testRendering
	| address |
	address := WAEmailAddress
		address: 'philippe.marschall@gmail.com'
		username: 'Philippe Marschall'.
	self assert: address address = 'philippe.marschall@gmail.com'.
	self assert: address username = 'Philippe Marschall'.
	self assert: (self render: address) = 'Philippe Marschall &lt;philippe.marschall@gmail.com&gt;'.! !

!WAEmailAddressTest methodsFor: 'testing' stamp: 'pmm 11/30/2008 15:31'!
testSeasideString
	| address |
	address := WAEmailAddress
		address: 'philippe.marschall@gmail.com'
		username: 'Philippe Marschall'.
	self assert: address seasideString = '"Philippe Marschall" <philippe.marschall@gmail.com>'! !
